@@ -1,12 +1,13 @@
 """utilities are functions that need to be used by multiple files."""
-from pathlib import Path
 from os import PathLike
+from pathlib import Path
+from typing import Union
 
 from ansible_generator.log import setup_logger
 
 logger = setup_logger(name=__name__)
 
-StrPath = str | PathLike[str]
+StrPath = Union[str, PathLike[str]]
 
 
 def join_cwd_and_directory_path(dir_path: StrPath) -> Path:
